@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -42,8 +40,7 @@ from google.cloud.websecurityscanner_v1.types import scan_run
 from google.cloud.websecurityscanner_v1.types import scan_run_error_trace
 from google.cloud.websecurityscanner_v1.types import scan_run_warning_trace
 from google.cloud.websecurityscanner_v1.types import web_security_scanner
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import WebSecurityScannerTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import WebSecurityScannerGrpcTransport
 from .transports.grpc_asyncio import WebSecurityScannerGrpcAsyncIOTransport
@@ -66,7 +63,7 @@ class WebSecurityScannerClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[WebSecurityScannerTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -93,7 +90,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -127,7 +125,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -144,7 +143,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -163,10 +162,11 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @property
     def transport(self) -> WebSecurityScannerTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            WebSecurityScannerTransport: The transport used by the client instance.
+            WebSecurityScannerTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
@@ -174,7 +174,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
     def finding_path(
         project: str, scan_config: str, scan_run: str, finding: str,
     ) -> str:
-        """Return a fully-qualified finding string."""
+        """Returns a fully-qualified finding string."""
         return "projects/{project}/scanConfigs/{scan_config}/scanRuns/{scan_run}/findings/{finding}".format(
             project=project,
             scan_config=scan_config,
@@ -184,7 +184,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def parse_finding_path(path: str) -> Dict[str, str]:
-        """Parse a finding path into its component segments."""
+        """Parses a finding path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/scanConfigs/(?P<scan_config>.+?)/scanRuns/(?P<scan_run>.+?)/findings/(?P<finding>.+?)$",
             path,
@@ -193,7 +193,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -206,7 +206,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -217,7 +217,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -228,7 +228,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -239,7 +239,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -253,12 +253,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, WebSecurityScannerTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the web security scanner client.
+        """Instantiates the web security scanner client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -313,9 +313,10 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -327,12 +328,14 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -347,8 +350,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -361,6 +364,10 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=(
+                    Transport == type(self).get_transport_class("grpc")
+                    or Transport == type(self).get_transport_class("grpc_asyncio")
+                ),
             )
 
     def create_scan_config(
@@ -377,7 +384,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.CreateScanConfigRequest):
                 The request object. Request for the `CreateScanConfig`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -391,7 +397,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.CreateScanConfigRequest.
         # There's no risk of modifying the input as we've already verified
@@ -430,7 +435,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.DeleteScanConfigRequest):
                 The request object. Request for the `DeleteScanConfig`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -438,7 +442,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.DeleteScanConfigRequest.
         # There's no risk of modifying the input as we've already verified
@@ -475,7 +478,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.GetScanConfigRequest):
                 The request object. Request for the `GetScanConfig`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -489,7 +491,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.GetScanConfigRequest.
         # There's no risk of modifying the input as we've already verified
@@ -527,7 +528,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.ListScanConfigsRequest):
                 The request object. Request for the `ListScanConfigs`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -543,7 +543,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.ListScanConfigsRequest.
         # There's no risk of modifying the input as we've already verified
@@ -588,7 +587,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.UpdateScanConfigRequest):
                 The request object. Request for the
                 `UpdateScanConfigRequest` method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -602,7 +600,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.UpdateScanConfigRequest.
         # There's no risk of modifying the input as we've already verified
@@ -642,7 +639,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.StartScanRunRequest):
                 The request object. Request for the `StartScanRun`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -657,7 +653,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.StartScanRunRequest.
         # There's no risk of modifying the input as we've already verified
@@ -694,7 +689,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         Args:
             request (google.cloud.websecurityscanner_v1.types.GetScanRunRequest):
                 The request object. Request for the `GetScanRun` method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -709,7 +703,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.GetScanRunRequest.
         # There's no risk of modifying the input as we've already verified
@@ -748,7 +741,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.ListScanRunsRequest):
                 The request object. Request for the `ListScanRuns`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -764,7 +756,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.ListScanRunsRequest.
         # There's no risk of modifying the input as we've already verified
@@ -808,7 +799,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.StopScanRunRequest):
                 The request object. Request for the `StopScanRun`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -823,7 +813,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.StopScanRunRequest.
         # There's no risk of modifying the input as we've already verified
@@ -861,7 +850,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.ListCrawledUrlsRequest):
                 The request object. Request for the `ListCrawledUrls`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -877,7 +865,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.ListCrawledUrlsRequest.
         # There's no risk of modifying the input as we've already verified
@@ -920,7 +907,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         Args:
             request (google.cloud.websecurityscanner_v1.types.GetFindingRequest):
                 The request object. Request for the `GetFinding` method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -935,7 +921,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.GetFindingRequest.
         # There's no risk of modifying the input as we've already verified
@@ -973,7 +958,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.ListFindingsRequest):
                 The request object. Request for the `ListFindings`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -989,7 +973,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.ListFindingsRequest.
         # There's no risk of modifying the input as we've already verified
@@ -1033,7 +1016,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             request (google.cloud.websecurityscanner_v1.types.ListFindingTypeStatsRequest):
                 The request object. Request for the
                 `ListFindingTypeStats` method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1045,7 +1027,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 Response for the ListFindingTypeStats method.
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a web_security_scanner.ListFindingTypeStatsRequest.
         # There's no risk of modifying the input as we've already verified
