@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,15 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -32,8 +30,7 @@ from google.cloud.websecurityscanner_v1alpha.types import scan_config
 from google.cloud.websecurityscanner_v1alpha.types import scan_config as gcw_scan_config
 from google.cloud.websecurityscanner_v1alpha.types import scan_run
 from google.cloud.websecurityscanner_v1alpha.types import web_security_scanner
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 from .base import WebSecurityScannerTransport, DEFAULT_CLIENT_INFO
 from .grpc import WebSecurityScannerGrpcTransport
 
@@ -61,7 +58,7 @@ class WebSecurityScannerGrpcAsyncIOTransport(WebSecurityScannerTransport):
     def create_channel(
         cls,
         host: str = "websecurityscanner.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -88,13 +85,15 @@ class WebSecurityScannerGrpcAsyncIOTransport(WebSecurityScannerTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -102,7 +101,7 @@ class WebSecurityScannerGrpcAsyncIOTransport(WebSecurityScannerTransport):
         self,
         *,
         host: str = "websecurityscanner.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
@@ -112,11 +111,13 @@ class WebSecurityScannerGrpcAsyncIOTransport(WebSecurityScannerTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -152,6 +153,8 @@ class WebSecurityScannerGrpcAsyncIOTransport(WebSecurityScannerTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -174,7 +177,6 @@ class WebSecurityScannerGrpcAsyncIOTransport(WebSecurityScannerTransport):
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-
         else:
             if api_mtls_endpoint:
                 host = api_mtls_endpoint
@@ -204,6 +206,7 @@ class WebSecurityScannerGrpcAsyncIOTransport(WebSecurityScannerTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -266,7 +269,7 @@ class WebSecurityScannerGrpcAsyncIOTransport(WebSecurityScannerTransport):
     def delete_scan_config(
         self,
     ) -> Callable[
-        [web_security_scanner.DeleteScanConfigRequest], Awaitable[empty.Empty]
+        [web_security_scanner.DeleteScanConfigRequest], Awaitable[empty_pb2.Empty]
     ]:
         r"""Return a callable for the delete scan config method over gRPC.
 
@@ -287,7 +290,7 @@ class WebSecurityScannerGrpcAsyncIOTransport(WebSecurityScannerTransport):
             self._stubs["delete_scan_config"] = self.grpc_channel.unary_unary(
                 "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/DeleteScanConfig",
                 request_serializer=web_security_scanner.DeleteScanConfigRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_scan_config"]
 
