@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -43,9 +41,8 @@ from google.cloud.websecurityscanner_v1beta.types import scan_run
 from google.cloud.websecurityscanner_v1beta.types import scan_run_error_trace
 from google.cloud.websecurityscanner_v1beta.types import scan_run_warning_trace
 from google.cloud.websecurityscanner_v1beta.types import web_security_scanner
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import WebSecurityScannerTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import WebSecurityScannerGrpcTransport
 from .transports.grpc_asyncio import WebSecurityScannerGrpcAsyncIOTransport
@@ -68,7 +65,7 @@ class WebSecurityScannerClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[WebSecurityScannerTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -95,7 +92,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -129,7 +127,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -146,7 +145,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -165,10 +164,11 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @property
     def transport(self) -> WebSecurityScannerTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            WebSecurityScannerTransport: The transport used by the client instance.
+            WebSecurityScannerTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
@@ -176,7 +176,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
     def finding_path(
         project: str, scan_config: str, scan_run: str, finding: str,
     ) -> str:
-        """Return a fully-qualified finding string."""
+        """Returns a fully-qualified finding string."""
         return "projects/{project}/scanConfigs/{scan_config}/scanRuns/{scan_run}/findings/{finding}".format(
             project=project,
             scan_config=scan_config,
@@ -186,7 +186,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def parse_finding_path(path: str) -> Dict[str, str]:
-        """Parse a finding path into its component segments."""
+        """Parses a finding path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/scanConfigs/(?P<scan_config>.+?)/scanRuns/(?P<scan_run>.+?)/findings/(?P<finding>.+?)$",
             path,
@@ -195,14 +195,14 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def scan_config_path(project: str, scan_config: str,) -> str:
-        """Return a fully-qualified scan_config string."""
+        """Returns a fully-qualified scan_config string."""
         return "projects/{project}/scanConfigs/{scan_config}".format(
             project=project, scan_config=scan_config,
         )
 
     @staticmethod
     def parse_scan_config_path(path: str) -> Dict[str, str]:
-        """Parse a scan_config path into its component segments."""
+        """Parses a scan_config path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/scanConfigs/(?P<scan_config>.+?)$", path
         )
@@ -210,14 +210,14 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def scan_run_path(project: str, scan_config: str, scan_run: str,) -> str:
-        """Return a fully-qualified scan_run string."""
+        """Returns a fully-qualified scan_run string."""
         return "projects/{project}/scanConfigs/{scan_config}/scanRuns/{scan_run}".format(
             project=project, scan_config=scan_config, scan_run=scan_run,
         )
 
     @staticmethod
     def parse_scan_run_path(path: str) -> Dict[str, str]:
-        """Parse a scan_run path into its component segments."""
+        """Parses a scan_run path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/scanConfigs/(?P<scan_config>.+?)/scanRuns/(?P<scan_run>.+?)$",
             path,
@@ -226,7 +226,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -239,7 +239,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -250,7 +250,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -261,7 +261,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -272,7 +272,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -286,12 +286,12 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, WebSecurityScannerTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the web security scanner client.
+        """Instantiates the web security scanner client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -346,9 +346,10 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -360,12 +361,14 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -380,8 +383,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -394,6 +397,10 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=(
+                    Transport == type(self).get_transport_class("grpc")
+                    or Transport == type(self).get_transport_class("grpc_asyncio")
+                ),
             )
 
     def create_scan_config(
@@ -428,7 +435,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``scan_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -457,10 +463,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.CreateScanConfigRequest):
             request = web_security_scanner.CreateScanConfigRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if scan_config is not None:
@@ -507,7 +511,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -530,10 +533,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.DeleteScanConfigRequest):
             request = web_security_scanner.DeleteScanConfigRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -576,7 +577,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -605,10 +605,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.GetScanConfigRequest):
             request = web_security_scanner.GetScanConfigRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -651,7 +649,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -682,10 +679,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.ListScanConfigsRequest):
             request = web_security_scanner.ListScanConfigsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -716,7 +711,7 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         request: web_security_scanner.UpdateScanConfigRequest = None,
         *,
         scan_config: gcw_scan_config.ScanConfig = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -746,7 +741,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -775,10 +769,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.UpdateScanConfigRequest):
             request = web_security_scanner.UpdateScanConfigRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if scan_config is not None:
                 request.scan_config = scan_config
             if update_mask is not None:
@@ -826,7 +818,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -856,10 +847,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.StartScanRunRequest):
             request = web_security_scanner.StartScanRunRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -902,7 +891,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -932,10 +920,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.GetScanRunRequest):
             request = web_security_scanner.GetScanRunRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -980,7 +966,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1011,10 +996,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.ListScanRunsRequest):
             request = web_security_scanner.ListScanRunsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1064,7 +1047,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1094,10 +1076,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.StopScanRunRequest):
             request = web_security_scanner.StopScanRunRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1141,7 +1121,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1172,10 +1151,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.ListCrawledUrlsRequest):
             request = web_security_scanner.ListCrawledUrlsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1224,7 +1201,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1254,10 +1230,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.GetFindingRequest):
             request = web_security_scanner.GetFindingRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1310,7 +1284,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1341,10 +1314,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.ListFindingsRequest):
             request = web_security_scanner.ListFindingsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if filter is not None:
@@ -1396,7 +1367,6 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1423,10 +1393,8 @@ class WebSecurityScannerClient(metaclass=WebSecurityScannerClientMeta):
         # there are no flattened fields.
         if not isinstance(request, web_security_scanner.ListFindingTypeStatsRequest):
             request = web_security_scanner.ListFindingTypeStatsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
