@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -90,8 +88,7 @@ class ScanConfigError(proto.Message):
         UNSUPPORTED_URL_SCHEME = 42
 
     code = proto.Field(proto.ENUM, number=1, enum=Code,)
-
-    field_name = proto.Field(proto.STRING, number=2)
+    field_name = proto.Field(proto.STRING, number=2,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
