@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.websecurityscanner_v1beta.types import crawled_url
 from google.cloud.websecurityscanner_v1beta.types import finding
 from google.cloud.websecurityscanner_v1beta.types import (
@@ -25,7 +22,7 @@ from google.cloud.websecurityscanner_v1beta.types import (
 )
 from google.cloud.websecurityscanner_v1beta.types import scan_config as gcw_scan_config
 from google.cloud.websecurityscanner_v1beta.types import scan_run
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -55,7 +52,6 @@ __protobuf__ = proto.module(
 
 class CreateScanConfigRequest(proto.Message):
     r"""Request for the ``CreateScanConfig`` method.
-
     Attributes:
         parent (str):
             Required. The parent resource name where the
@@ -66,8 +62,7 @@ class CreateScanConfigRequest(proto.Message):
             Required. The ScanConfig to be created.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     scan_config = proto.Field(
         proto.MESSAGE, number=2, message=gcw_scan_config.ScanConfig,
     )
@@ -75,7 +70,6 @@ class CreateScanConfigRequest(proto.Message):
 
 class DeleteScanConfigRequest(proto.Message):
     r"""Request for the ``DeleteScanConfig`` method.
-
     Attributes:
         name (str):
             Required. The resource name of the ScanConfig
@@ -83,12 +77,11 @@ class DeleteScanConfigRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}'.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class GetScanConfigRequest(proto.Message):
     r"""Request for the ``GetScanConfig`` method.
-
     Attributes:
         name (str):
             Required. The resource name of the ScanConfig
@@ -96,12 +89,11 @@ class GetScanConfigRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}'.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListScanConfigsRequest(proto.Message):
     r"""Request for the ``ListScanConfigs`` method.
-
     Attributes:
         parent (str):
             Required. The parent resource name, which
@@ -119,16 +111,13 @@ class ListScanConfigsRequest(proto.Message):
             reasonable value.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_token = proto.Field(proto.STRING, number=2)
-
-    page_size = proto.Field(proto.INT32, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_token = proto.Field(proto.STRING, number=2,)
+    page_size = proto.Field(proto.INT32, number=3,)
 
 
 class UpdateScanConfigRequest(proto.Message):
     r"""Request for the ``UpdateScanConfigRequest`` method.
-
     Attributes:
         scan_config (google.cloud.websecurityscanner_v1beta.types.ScanConfig):
             Required. The ScanConfig to be updated. The
@@ -144,13 +133,13 @@ class UpdateScanConfigRequest(proto.Message):
     scan_config = proto.Field(
         proto.MESSAGE, number=2, message=gcw_scan_config.ScanConfig,
     )
-
-    update_mask = proto.Field(proto.MESSAGE, number=3, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
+    )
 
 
 class ListScanConfigsResponse(proto.Message):
     r"""Response for the ``ListScanConfigs`` method.
-
     Attributes:
         scan_configs (Sequence[google.cloud.websecurityscanner_v1beta.types.ScanConfig]):
             The list of ScanConfigs returned.
@@ -167,13 +156,11 @@ class ListScanConfigsResponse(proto.Message):
     scan_configs = proto.RepeatedField(
         proto.MESSAGE, number=1, message=gcw_scan_config.ScanConfig,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class StartScanRunRequest(proto.Message):
     r"""Request for the ``StartScanRun`` method.
-
     Attributes:
         name (str):
             Required. The resource name of the ScanConfig
@@ -181,12 +168,11 @@ class StartScanRunRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}'.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class GetScanRunRequest(proto.Message):
     r"""Request for the ``GetScanRun`` method.
-
     Attributes:
         name (str):
             Required. The resource name of the ScanRun to
@@ -194,12 +180,11 @@ class GetScanRunRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListScanRunsRequest(proto.Message):
     r"""Request for the ``ListScanRuns`` method.
-
     Attributes:
         parent (str):
             Required. The parent resource name, which
@@ -217,16 +202,13 @@ class ListScanRunsRequest(proto.Message):
             reasonable value.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_token = proto.Field(proto.STRING, number=2)
-
-    page_size = proto.Field(proto.INT32, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_token = proto.Field(proto.STRING, number=2,)
+    page_size = proto.Field(proto.INT32, number=3,)
 
 
 class ListScanRunsResponse(proto.Message):
     r"""Response for the ``ListScanRuns`` method.
-
     Attributes:
         scan_runs (Sequence[google.cloud.websecurityscanner_v1beta.types.ScanRun]):
             The list of ScanRuns returned.
@@ -241,13 +223,11 @@ class ListScanRunsResponse(proto.Message):
         return self
 
     scan_runs = proto.RepeatedField(proto.MESSAGE, number=1, message=scan_run.ScanRun,)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class StopScanRunRequest(proto.Message):
     r"""Request for the ``StopScanRun`` method.
-
     Attributes:
         name (str):
             Required. The resource name of the ScanRun to
@@ -255,12 +235,11 @@ class StopScanRunRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListCrawledUrlsRequest(proto.Message):
     r"""Request for the ``ListCrawledUrls`` method.
-
     Attributes:
         parent (str):
             Required. The parent resource name, which
@@ -278,16 +257,13 @@ class ListCrawledUrlsRequest(proto.Message):
             reasonable value.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_token = proto.Field(proto.STRING, number=2)
-
-    page_size = proto.Field(proto.INT32, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_token = proto.Field(proto.STRING, number=2,)
+    page_size = proto.Field(proto.INT32, number=3,)
 
 
 class ListCrawledUrlsResponse(proto.Message):
     r"""Response for the ``ListCrawledUrls`` method.
-
     Attributes:
         crawled_urls (Sequence[google.cloud.websecurityscanner_v1beta.types.CrawledUrl]):
             The list of CrawledUrls returned.
@@ -304,13 +280,11 @@ class ListCrawledUrlsResponse(proto.Message):
     crawled_urls = proto.RepeatedField(
         proto.MESSAGE, number=1, message=crawled_url.CrawledUrl,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetFindingRequest(proto.Message):
     r"""Request for the ``GetFinding`` method.
-
     Attributes:
         name (str):
             Required. The resource name of the Finding to
@@ -318,12 +292,11 @@ class GetFindingRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}/findings/{findingId}'.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListFindingsRequest(proto.Message):
     r"""Request for the ``ListFindings`` method.
-
     Attributes:
         parent (str):
             Required. The parent resource name, which
@@ -345,18 +318,14 @@ class ListFindingsRequest(proto.Message):
             reasonable value.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    filter = proto.Field(proto.STRING, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
-
-    page_size = proto.Field(proto.INT32, number=4)
+    parent = proto.Field(proto.STRING, number=1,)
+    filter = proto.Field(proto.STRING, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
+    page_size = proto.Field(proto.INT32, number=4,)
 
 
 class ListFindingsResponse(proto.Message):
     r"""Response for the ``ListFindings`` method.
-
     Attributes:
         findings (Sequence[google.cloud.websecurityscanner_v1beta.types.Finding]):
             The list of Findings returned.
@@ -371,13 +340,11 @@ class ListFindingsResponse(proto.Message):
         return self
 
     findings = proto.RepeatedField(proto.MESSAGE, number=1, message=finding.Finding,)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class ListFindingTypeStatsRequest(proto.Message):
     r"""Request for the ``ListFindingTypeStats`` method.
-
     Attributes:
         parent (str):
             Required. The parent resource name, which
@@ -385,12 +352,11 @@ class ListFindingTypeStatsRequest(proto.Message):
             'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
+    parent = proto.Field(proto.STRING, number=1,)
 
 
 class ListFindingTypeStatsResponse(proto.Message):
     r"""Response for the ``ListFindingTypeStats`` method.
-
     Attributes:
         finding_type_stats (Sequence[google.cloud.websecurityscanner_v1beta.types.FindingTypeStats]):
             The list of FindingTypeStats returned.
